<?php

namespace MainWP\Extensions\SSL_Monitor;

class MainWP_SSL_Monitor_Dashboard {

	// Singleton
	private static $instance = null;

	/**
	 * Get Instance
	 *
	 * Creates public static instance.
	 *
	 * @static
	 *
	 * @return MainWP_SSL_Monitor_Dashboard
	 */
	static function get_instance() {
		if ( null == self::$instance ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	public function __construct() {
	}

	public function admin_init() {
		add_action( 'wp_ajax_mainwp_ssl_monitor_check_site_certificate', array( $this, 'ajax_ssl_check' ) );
	}

	/**
	 * Render Actions Bar
	 *
	 * Renders the actions bar on the Dashboard tab.
	 */
	public static function render_actions_bar() {
		$page  = 'admin.php?page=Extensions-Mainwp-SSL-Monitor-Extension';
		$nonce = wp_create_nonce( 'ssl_monitor_nonce' );
		?>
		<div class="mainwp-actions-bar">
			<div class="ui two columns grid">
				<div class="column ui mini form">
					<select class="ui mini dropdown" id="mainwp-ssl-monitor-bulk-actions-menu">
						<option value="-1"><?php _e( 'Bulk actions', 'mainwp-ssl-monitor-extension' ); ?></option>
						<option value="check-sites"><?php _e( 'Check SSL Certificate', 'mainwp-ssl-monitor-extension' ); ?></option>
						<option value="open-wpadmin"><?php _e( 'Go to WP Admin', 'mainwp-ssl-monitor-extension' ); ?></option>
						<option value="open-frontpage"><?php _e( 'Go to Site', 'mainwp-ssl-monitor-extension' ); ?></option>
					</select>
					<input type="button" name="mainwp-ssl-monitor-bulk-actions-button" id="mainwp-ssl-monitor-bulk-actions-button" class="ui basic mini button" value="<?php _e( 'Apply', 'mainwp-ssl-monitor-extension' ); ?>"/>
				</div>
				<div class="right aligned middle aligned column">
					<a href="admin.php?page=Extensions-Mainwp-Ssl-Monitor-Extension&tab=dashboard&action=ssl_check&ssl_monitor_nonce=<?php echo wp_create_nonce( 'ssl_monitor_nonce' ); ?>" id="mainwp-ssl-check-start-button" class="ui mini green button" data-tooltip="<?php echo __( 'Click to start the SSL Certificate check process for all sites.', 'mainwp-ssl-monitor-extension' ); ?>" data-inverted="" data-position="bottom right"><?php _e( 'Check SSL Certificate on All Sites', 'mainwp-ssl-monitor-extension' ); ?></a>
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Render the Dashbaord tab
	 *
	 * Renders the dashbaord tab content - Development table
	 *
	 * @param array $websites Child sites.
	 */
	public static function gen_dashboard_tab() {

		$websites = MainWP_SSL_Monitor_Utility::get_websites();
		if ( isset( $_GET['action'] ) && 'ssl_check' == $_GET['action'] && isset( $_GET['ssl_monitor_nonce'] ) && wp_verify_nonce( sanitize_text_field( $_GET['ssl_monitor_nonce'] ), 'ssl_monitor_nonce' ) ) {
			return self::mainwp_ssl_monitor_modal();
		}

		?>
		<table class="ui single line table" id="mainwp-ssl-monitor-sites-table" style="width:100%">
			<thead>
				<tr>
					<th class="no-sort collapsing check-column"><span class="ui checkbox"><input type="checkbox" id="cb-select-all-top"></span></th>
					<th id="site" class="collapsing"><?php _e( 'Site', 'mainwp-ssl-monitor-extension' ); ?></th>
					<th id="sign-in" class="no-sort collapsing"><i class="sign in icon"></i></th>
					<th id="url" class="collapsing"><?php _e( 'URL', 'mainwp-ssl-monitor-extension' ); ?></th>
					<th id="expires" class="collapsing"><?php _e( 'Expires', 'mainwp-domain-monitor-extension' ); ?></th>
					<th id="last-check" class="collapsing"><?php _e( 'Last Check', 'mainwp-domain-monitor-extension' ); ?></th>
					<th id="cn" class="collapsing"><?php _e( 'Common Name', 'mainwp-ssl-monitor-extension' ); ?></th>
					<th id="issuer" class="collapsing"><?php _e( 'Issuer', 'mainwp-domain-monitor-extension' ); ?></th>
					<th id="valid-from" class="collapsing"><?php _e( 'Valid From', 'mainwp-ssl-monitor-extension' ); ?></th>
					<th id="valid-to" class="collapsing"><?php _e( 'Valid To', 'mainwp-ssl-monitor-extension' ); ?></th>
					<th id="actions" class="no-sort collapsing right aligned"></th>
				</tr>
			</thead>
			<tbody>
				<?php self::render_dashboard_table_row( $websites ); ?>
			</tbody>
			<tfoot>
				<tr>
					<th class="no-sort collapsing check-column"><span class="ui checkbox"><input type="checkbox" id="cb-select-all-bottom"></span></th>
					<th><?php _e( 'Site', 'mainwp-ssl-monitor-extension' ); ?></th>
					<th class="no-sort collapsing"><i class="sign in icon"></i></th>
					<th><?php _e( 'URL', 'mainwp-ssl-monitor-extension' ); ?></th>
					<th class="collapsing"><?php _e( 'Expires', 'mainwp-domain-monitor-extension' ); ?></th>
					<th class="collapsing"><?php _e( 'Last Check', 'mainwp-domain-monitor-extension' ); ?></th>
					<th class="collapsing"><?php _e( 'Common Name', 'mainwp-ssl-monitor-extension' ); ?></th>
					<th class="collapsing"><?php _e( 'Issuer', 'mainwp-domain-monitor-extension' ); ?></th>
					<th class="collapsing"><?php _e( 'Valid From', 'mainwp-ssl-monitor-extension' ); ?></th>
					<th class="collapsing"><?php _e( 'Valid To', 'mainwp-ssl-monitor-extension' ); ?></th>
					<th class="no-sort collapsing"></th>
				</tr>
			</tfoot>
		</table>
		<?php self::render_screen_options(); ?>
		<script type="text/javascript">
		jQuery( function () {
			$ssl_monitor_sites_table = jQuery( '#mainwp-ssl-monitor-sites-table' ).DataTable( {
				"stateSave": true,
				"stateDuration": 0,
				"scrollX": true,
				"colReorder" : { columns: ":not(.check-column):not(:last-child)" },
				"lengthMenu": [ [10, 25, 50, 100, -1], [10, 25, 50, 100, "All"] ],
				"columnDefs": [ { "targets": 'no-sort', "orderable": false } ],
				"order": [ [ 1, "asc" ] ],
				"language": { "emptyTable": "No websites found." },
				"drawCallback": function( settings ) {
					jQuery('#mainwp-ssl-monitor-sites-table .ui.checkbox').checkbox();
					jQuery( '#mainwp-ssl-monitor-sites-table .ui.dropdown').dropdown();
					mainwp_datatable_fix_menu_overflow('#mainwp-ssl-monitor-sites-table' );
				},
				'select': {
					items: 'row',
					style: 'multi+shift',
					selector: 'tr>td:not(.not-selectable)'
				}
			} ).on('select', function (e, dt, type, indexes) {
				if( 'row' == type ){
					dt.rows(indexes)
					.nodes()
					.to$().find('td.check-column .ui.checkbox' ).checkbox('set checked');
				}
			}).on('deselect', function (e, dt, type, indexes) {
				if( 'row' == type ){
					dt.rows(indexes)
					.nodes()
					.to$().find('td.check-column .ui.checkbox' ).checkbox('set unchecked');
				}
			}).on( 'columns-reordered', function ( e, settings, details ) {
				console.log('columns-reordered');
				setTimeout(() => {
					jQuery( '#mainwp-ssl-monitor-sites-table .ui.dropdown' ).dropdown();
					jQuery( '#mainwp-ssl-monitor-sites-table .ui.checkbox' ).checkbox();
					mainwp_datatable_fix_menu_overflow('#mainwp-ssl-monitor-sites-table' );
				}, 1000);
			} );;

			jQuery('#mainwp-ssl-monitor-sites-table .ui.checkbox').checkbox();
			jQuery( '#mainwp-ssl-monitor-sites-table .ui.dropdown').dropdown();
			mainwp_datatable_fix_menu_overflow('#mainwp-ssl-monitor-sites-table' );

			_init_ssl_monitor_sites_screen = function() {
				jQuery( '#mainwp-ssl-monitor-sites-screen-options-modal input[type=checkbox][id^="mainwp_show_column_"]' ).each( function() {
					var check_id = jQuery( this ).attr( 'id' );
					col_id = check_id.replace( "mainwp_show_column_", "" );
					try {
						$ssl_monitor_sites_table.column( '#' + col_id ).visible( jQuery( this ).is( ':checked' ) );
						if ( check_id.indexOf( "mainwp_show_column_desktop" ) >= 0 ) {
							col_id = check_id.replace( "mainwp_show_column_desktop", "" );
							$ssl_monitor_sites_table.column( '#mobile' + col_id ).visible( jQuery( this ).is( ':checked' ) ); // to set mobile columns.
						}
					} catch( err ) {
						// to fix js error.
					}
				} );
			};
			_init_ssl_monitor_sites_screen();

			mainwp_ssl_monitor_sites_screen_options = function () {
				jQuery( '#mainwp-ssl-monitor-sites-screen-options-modal' ).modal( {
					allowMultiple: true,
					onHide: function () {
					}
				} ).modal( 'show' );

				jQuery( '#ssl-monitor-sites-screen-options-form' ).submit( function() {
					if ( jQuery('input[name=reset_sslmonitorsites_columns_order]').attr( 'value' ) == 1 ) {
						$ssl_monitor_sites_table.colReorder.reset();
					}
					jQuery( '#mainwp-ssl-monitor-sites-screen-options-modal' ).modal( 'hide' );
				} );
				return false;
			};

		} );
		</script>
		<?php
	}

	/**
	 * Render SSL Monitor Table Row
	 *
	 * Gets the SSL Monitor dashbaord table row.
	 *
	 * @param array $websites Child sites.
	 */
	public static function render_dashboard_table_row( $websites ) {
		foreach ( $websites as $website ) {
			$website_id = $website['id'];
			$ssl_data   = MainWP_SSL_Monitor_DB::get_instance()->get_ssl_monitor_by( 'site_id', $website_id );

			if ( ! empty( $ssl_data->valid_to ) ) {
				$expires = round( ( intval( $ssl_data->valid_to ) - time() ) / ( 60 * 60 * 24 ) );
			} else {
				$expires = 0;
			}

			$color_code = 'green';
			if ( 30 > $expires && $expires >= 1 ) {
				$color_code = 'yellow';
			} elseif ( 1 > $expires ) {
				$color_code = 'red';
			}

			$last_check_time = 'Not checked';

			if ( ! empty( $ssl_data->last_check ) ) {
				if ( $ssl_data->last_check > $ssl_data->last_auto_check ) {
					$last_check_time = $ssl_data->last_check;
				} else {
					$last_check_time = $ssl_data->last_auto_check;
				}
			}

			?>
			<?php if ( MainWP_SSL_Monitor_Utility::starts_with( $website['url'], 'https://' ) ) : ?>
			<tr class="" website-id="<?php echo $website_id; ?>">
				<td class="check-column"><span class="ui checkbox" data-tooltip="<?php esc_attr_e( 'Click to select the site.', 'mainwp-ssl-monitor-extension' ); ?>" data-inverted="" data-position="right center"><input type="checkbox" name="checked[]"></span></td>
				<td><a href="admin.php?page=managesites&dashboard=<?php echo $website_id; ?>" data-tooltip="<?php esc_attr_e( 'Go to the site overview.', 'mainwp-ssl-monitor-extension' ); ?>" data-inverted="" data-position="right center" class="mainwp-site-name-link"><?php echo stripslashes( $website['name'] ); ?></a></td>
				<td><a target="_blank" href="admin.php?page=SiteOpen&newWindow=yes&websiteid=<?php echo $website_id; ?>&_opennonce=<?php echo wp_create_nonce( 'mainwp-admin-nonce' ); ?>" class="open_newwindow_wpadmin" data-tooltip="<?php esc_attr_e( 'Jump to the WP Admin.', 'mainwp-ssl-monitor-extension' ); ?>" data-inverted="" data-position="right center"><i class="sign in icon"></i></a></td>
				<td><a href="<?php echo $website['url']; ?>" target="_blank" class="open_site_url" data-tooltip="<?php esc_attr_e( 'Go to the website.', 'mainwp-ssl-monitor-extension' ); ?>" data-inverted="" data-position="right center"><?php echo $website['url']; ?></a></td>
				<td data-sort="<?php echo empty( $expires ) ? '' : $expires; ?>"><span class="ui <?php echo $color_code; ?> fluid mini center aligned label"><?php echo empty( $expires ) ? 'N/A' : $expires . __( ' days', 'mainwp-domain-monitor-extension' ); ?></span></td>
				<td><?php echo MainWP_SSL_Monitor_Utility::format_datestamp( MainWP_SSL_Monitor_Utility::get_timestamp( $last_check_time ) ); ?></td>
				<td><?php echo empty( $ssl_data->common_name ) ? '' : $ssl_data->common_name; ?></td>
				<td><?php echo empty( $ssl_data->issuer_o ) ? '' : $ssl_data->issuer_o; ?></td>
				<td><?php echo empty( $ssl_data->valid_from ) ? '' : MainWP_SSL_Monitor_Utility::format_datestamp( MainWP_SSL_Monitor_Utility::get_timestamp( $ssl_data->valid_from ) ); ?></td>
				<td><?php echo empty( $ssl_data->valid_to ) ? '' : MainWP_SSL_Monitor_Utility::format_datestamp( MainWP_SSL_Monitor_Utility::get_timestamp( $ssl_data->valid_to ) ); ?></td>
				<td class="right aligned not-selectable">
					<div class="ui right pointing dropdown icon mini basic green button" >
						<a href="javascript:void(0)" data-tooltip="<?php esc_attr_e( 'See more options', 'mainwp-ssl-monitor-extension' ); ?>" data-position="left center" data-inverted=""><i class="ellipsis horizontal icon"></i></a>
						<div class="menu">
							<a class="item ssl-monitor-action-recheck" href="javascript:void(0)"><?php _e( 'Check SSL Certificate', 'mainwp-ssl-monitor-extension' ); ?></a>
							<a class="item" href="admin.php?page=ManageSitesSSLMonitor&id=<?php echo $website_id; ?>"><?php _e( 'SSL Certificate Info', 'mainwp-ssl-monitor-extension' ); ?></a>
							<a class="item" href="admin.php?page=managesites&dashboard=<?php echo $website_id; ?>"><?php _e( 'Overview', 'mainwp-ssl-monitor-extension' ); ?></a>
							<a class="item" href="admin.php?page=managesites&id=<?php echo $website_id; ?>"><?php _e( 'Edit', 'mainwp-ssl-monitor-extension' ); ?></a>
						</div>
					</div>
				</td>
			</tr>

			<?php endif; ?>
			<?php
		}
	}

	/**
	 * Get columns.
	 *
	 * @return array Array of column names.
	 */
	public static function get_columns() {
		return array(
			'site'       => __( 'Site', 'mainwp-ssl-monitor-extension' ),
			'sign-in'    => '<i class="sign in icon"></i>',
			'url'        => __( 'URL', 'mainwp-ssl-monitor-extension' ),
			'last-check' => __( 'Last Check', 'mainwp-ssl-monitor-extension' ),
			'expires'    => __( 'Expires', 'mainwp-ssl-monitor-extension' ),
			'cn'         => __( 'Common Name', 'mainwp-ssl-monitor-extension' ),
			'issuer'     => __( 'Issuer', 'mainwp-ssl-monitor-extension' ),
			'valid-from' => __( 'Valid From', 'mainwp-ssl-monitor-extension' ),
			'valid-to'   => __( 'Valid To', 'mainwp-ssl-monitor-extension' ),
			'actions'    => __( 'Action', 'mainwp-ssl-monitor-extension' ),
		);
	}

	/**
	 * Render screen options.
	 *
	 * @return array Array of default column names.
	 */
	public static function render_screen_options() {

		$columns = self::get_columns();

		$show_cols = get_user_option( 'mainwp_settings_show_ssl_monitor_sites_columns' );

		if ( ! is_array( $show_cols ) ) {
			$show_cols = array();
		}

		?>
		<div class="ui modal" id="mainwp-ssl-monitor-sites-screen-options-modal">
			<div class="header"><?php esc_html_e( 'Page Settings', 'mainwp' ); ?></div>
			<div class="scrolling content ui form">
				<form method="POST" action="" id="ssl-monitor-sites-screen-options-form" name="ssl_monitor_sites_screen_options_form">
					<?php wp_nonce_field( 'mainwp-admin-nonce' ); ?>
					<input type="hidden" name="wp_nonce" value="<?php echo wp_create_nonce( 'SSLMonitorSitesScrOptions' ); ?>" />
						<div class="ui grid field">
							<label class="six wide column"><?php esc_html_e( 'Show columns', 'mainwp' ); ?></label>
							<div class="ten wide column">
								<ul class="mainwp_hide_wpmenu_checkboxes">
									<?php
									foreach ( $columns as $name => $title ) {
										?>
										<li>
											<div class="ui checkbox">
												<input type="checkbox"
												<?php
												$show_col = ! isset( $show_cols[ $name ] ) || ( 1 == $show_cols[ $name ] );
												if ( $show_col ) {
													echo 'checked="checked"';
												}
												?>
												id="mainwp_show_column_<?php echo esc_attr( $name ); ?>" name="mainwp_show_column_<?php echo esc_attr( $name ); ?>" value="<?php echo esc_attr( $name ); ?>">
												<label for="mainwp_show_column_<?php echo esc_attr( $name ); ?>" ><?php echo $title; ?></label>
												<input type="hidden" value="<?php echo esc_attr( $name ); ?>" name="show_columns_name[]" />
											</div>
										</li>
										<?php
									}
									?>
								</ul>
							</div>
					</div>
				</div>
			<div class="actions">
					<div class="ui two columns grid">
						<div class="left aligned column">
							<span data-tooltip="<?php esc_attr_e( 'Returns this page to the state it was in when installed. The feature also restores any column you have moved through the drag and drop feature on the page.', 'mainwp-ssl-monitor-extension' ); ?>" data-inverted="" data-position="top center"><input type="button" class="ui button" name="reset" id="reset-sslmonitorsites-settings" value="<?php esc_attr_e( 'Reset Page', 'mainwp-ssl-monitor-extension' ); ?>" /></span>
						</div>
						<div class="ui right aligned column">
					<input type="submit" class="ui green button" name="btnSubmit" id="submit-sslmonitorsites-settings" value="<?php esc_attr_e( 'Save Settings', 'mainwp-ssl-monitor-extension' ); ?>" />
					<div class="ui cancel button"><?php esc_html_e( 'Close', 'mainwp-ssl-monitor-extension' ); ?></div>
				</div>
					</div>
				</div>
				<input type="hidden" name="reset_sslmonitorsites_columns_order" value="0">
			</form>
		</div>
		<div class="ui small modal" id="mainwp-ssl-monitor-sites-site-preview-screen-options-modal">
			<div class="header"><?php esc_html_e( 'Page Settings', 'mainwp-ssl-monitor-extension' ); ?></div>
			<div class="scrolling content ui form">
				<span><?php esc_html_e( 'Would you like to turn on home screen previews? This function queries WordPress.com servers to capture a screenshot of your site the same way comments shows you preview of URLs.', 'mainwp-ssl-monitor-extension' ); ?>
			</div>
			<div class="actions">
				<div class="ui ok button"><?php esc_html_e( 'Yes', 'mainwp-ssl-monitor-extension' ); ?></div>
				<div class="ui cancel button"><?php esc_html_e( 'No', 'mainwp-ssl-monitor-extension' ); ?></div>
			</div>
		</div>
		<script type="text/javascript">
			jQuery( document ).ready( function () {
				jQuery( '#reset-ssl-monitor-settings' ).on( 'click', function () {
					mainwp_confirm( __( 'Are you sure.' ), function() {
						jQuery( '.mainwp_hide_wpmenu_checkboxes input[id^="mainwp_show_column_"]' ).prop( 'checked', false );
						//default columns
						var cols = ['site','url','actions'];
						jQuery.each( cols, function ( index, value ) {
							jQuery( '.mainwp_hide_wpmenu_checkboxes input[id="mainwp_show_column_' + value + '"]' ).prop( 'checked', true );
						} );
						jQuery( 'input[name=reset_sslmonitorsites_columns_order]' ).attr( 'value', 1 );
						jQuery( '#submit-sslmonitorsites-settings' ).click();
					}, false, false, true );
					return false;
				} );
			} );
		</script>
		<?php
	}

	/**
	 * SSL Monitor Modal
	 *
	 * Renders the progress modal.
	 *
	 * @return bool True on success, false on failure.
	 */
	public static function mainwp_ssl_monitor_modal() {
		$websites  = MainWP_SSL_Monitor_Utility::get_websites();
		$sites_ids = array();
		if ( is_array( $websites ) ) {
			foreach ( $websites as $website ) {
				$sites_ids[] = $website['id'];
			}
		}

		$dbwebsites = MainWP_SSL_Monitor_Utility::get_db_sites( $sites_ids );

		$sites_to_process = array();

		if ( $dbwebsites ) {
			foreach ( $dbwebsites as $website ) {
				$sites_to_process[] = MainWP_SSL_Monitor_Utility::map_fields( $website, array( 'id', 'name' ) );
			}
		}
		?>
		<?php if ( count( $sites_to_process ) > 0 ) : ?>
		<div class="ui modal" id="mainwp-ssl-monitor-sync-modal">
			<div class="header"><?php _e( 'SSL Certificate Check', 'mainwp-ssl-monitor-extension' ); ?></div>
			<div class="ui green progress mainwp-modal-progress">
				<div class="bar"><div class="progress"></div></div>
				<div class="label"></div>
			</div>
			<div class="scrolling content">
				<div class="ui message" id="mainwp-ssl-monitor-modal-progress-feedback" style="display:none"></div>
				<div class="ui relaxed divided list">
					<?php foreach ( $sites_to_process as $website ) : ?>
						<div class="item" siteid="<?php echo $website['id']; ?>" status="queue">
							<a href="admin.php?page=managesites&dashboard=<?php echo $website['id']; ?>" data-tooltip="<?php esc_attr_e( 'Go to the site Overview page.', 'mainwp-ssl-monitor-extension' ); ?>" data-inverted="" data-position="right center"><?php echo $website['name']; ?></a>
							<span class="right floated status"><span data-tooltip="<?php esc_attr_e( 'Pending.', 'mainwp-ssl-monitor-extension' ); ?>" data-inverted="" data-position="left center"><i class="clock outline icon"></i></span></span>
						</div>
					<?php endforeach; ?>
				</div>
			</div>
			<div class="actions">
				<div class="ui cancel reload button"><?php _e( 'Close', 'mainwp-ssl-monitor-extension' ); ?></div>
			</div>
		</div>
		<script type="text/javascript">
			jQuery( document ).ready( function() {
			jQuery( '#mainwp-ssl-monitor-sync-modal' ).modal( 'show' );
			mainwp_ssl_monitor_start_next();
			} );
		</script>
			<?php return true; ?>
		<?php else : ?>
		<div class="ui yellow message"><?php _e( 'Sites not found.', 'mainwp-ssl-monitor-extension' ); ?></div>
		<?php endif; ?>
		<?php
		return false;
	}

	/**
	 * SSL check AJAX
	 *
	 * Performs the SSL Certificate check via AJAX request.
	 */
	public function ajax_ssl_check() {
		MainWP_SSL_Monitor_Admin::check_security();

		$site_id = isset( $_POST['websiteId'] ) ? $_POST['websiteId'] : null;
		$id      = isset( $_POST['item_id'] ) ? $_POST['item_id'] : 0;

		if ( $site_id ) {
			$dbwebsites = MainWP_SSL_Monitor_Utility::get_db_sites( array( $site_id ) );

			if ( is_array( $dbwebsites ) && ! empty( $dbwebsites ) ) {
				$website  = current( $dbwebsites );
				$site_url = $website->url;
			}
		}

		if ( MainWP_SSL_Monitor_Utility::starts_with( $site_url, 'https://' ) ) {
			if ( $site_id && ! empty( $site_url ) ) {
				$result = MainWP_SSL_Monitor_Utility::get_ssl_certificate_info( $site_url, $id, $site_id );
				if ( is_array( $result ) && isset( $result['error'] ) ) {
					die( wp_json_encode( array( 'error' => esc_html( $result['error'] ) ) ) );
				}

				die( wp_json_encode( array( 'status' => 'success' ) ) );
			}
			die( wp_json_encode( array( 'error' => __( 'Invalid site ID. Please reload and try again.', 'mainwp-ssl-monitor-extension' ) ) ) );
		}

		die( wp_json_encode( array( 'error' => __( 'HTTP site. SSL Certificate not detected.', 'mainwp-ssl-monitor-extension' ) ) ) );
	}
}
