<?php
namespace MainWP\Extensions\SSL_Monitor;

class MainWP_SSL_Monitor_DB_Schedule extends MainWP_SSL_Monitor_DB {

	/**
	 * Static variable to hold the single instance of the class.
	 *
	 * @static
	 *
	 * @var mixed Default null
	 */
	private static $instance = null;

	/**
	 * Get Instance
	 *
	 * Creates public static instance.
	 *
	 * @static
	 *
	 * @return class
	 */
	public static function get_instance() {
		if ( null == self::$instance ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	// Constructor
	public function __construct() {
		parent::__construct();
	}


	public function update_to_start_auto_check() {
		/** @var $wpdb wpdb */
		global $wpdb;
		$time = time();
		return $wpdb->query(
			'
			UPDATE ' . $this->table_name( 'ssl_monitor' ) . " SET last_auto_check  = $time 
			WHERE ( use_schedule = 1 AND overwrite = 1 ) OR ( overwrite = 0 )"
		);
	}

	public function get_to_continue_auto_check() {
		global $wpdb;
		$sql = 'SELECT * FROM ' . $this->table_name( 'ssl_monitor' ) . ' 
		WHERE ( completed_auto_check = 0 OR completed_auto_check <= last_auto_check ) AND site_id != 0
		AND ( ( use_schedule = 1 AND overwrite = 1 ) OR ( overwrite = 0 ) ) 
		';
		return $wpdb->get_results( $sql );
	}

	public function update_completed_auto_check_for_site( $site_id ) {
		/** @var $wpdb wpdb */
		global $wpdb;

		$current = $this->get_ssl_monitor_by( 'site_id', $site_id );
		if ( ! empty( $current ) ) {
			$wpdb->update(
				$this->table_name( 'ssl_monitor' ),
				array(
					'completed_auto_check' => time(),
				),
				array( 'site_id' => $site_id )
			);
			return $this->get_ssl_monitor_by( 'site_id', $site_id );
		}
		return false;
	}

	public function update_to_start_auto_alert() {
		/** @var $wpdb wpdb */
		global $wpdb;
		$time = time();
		return $wpdb->query(
			'
			UPDATE ' . $this->table_name( 'ssl_monitor' ) . " SET last_auto_alert  = $time 
			WHERE ( use_schedule = 1 AND overwrite = 1 ) OR ( overwrite = 0 )"
		);
	}

	public function get_to_continue_auto_alert() {
		global $wpdb;
		$sql = 'SELECT * FROM ' . $this->table_name( 'ssl_monitor' ) . ' 
		WHERE ( completed_auto_alert = 0 OR completed_auto_alert <= last_auto_alert ) AND site_id != 0
		AND ( ( use_schedule = 1 AND overwrite = 1 ) OR ( overwrite = 0 ) ) ';
		return $wpdb->get_results( $sql );
	}

	public function update_completed_auto_alert_for_site( $site_id ) {
		/** @var $wpdb wpdb */
		global $wpdb;

		$current = $this->get_ssl_monitor_by( 'site_id', $site_id );
		if ( ! empty( $current ) ) {
			$wpdb->update( $this->table_name( 'ssl_monitor' ), array( 'completed_auto_alert' => time() ), array( 'site_id' => $site_id ) );
			return $this->get_ssl_monitor_by( 'site_id', $site_id );
		}
		return false;
	}

}
